@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -548,7 +548,7 @@ SCIP_RETCODE setColumnMajorFormat(
    int* rowpnt;
    int* rowend;
    SCIP_Real* valpnt;
-   SCIP_RATIONAL* valpntrational;
+   SCIP_RATIONAL* valpntrational = NULL;
    int* fillidx;
 
    assert(scip != NULL);
