@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -65,6 +65,7 @@ using namespace scip;
 #endif
 
 /** print SCIP_RATIONAL to output stream */
+static
 std::ostream& operator<<(
    std::ostream&         os,                 /**< output stream */
    SCIP_RATIONAL const & r                   /**< rational to print */
@@ -1834,10 +1835,8 @@ void SCIPrationalPrint(
 {
    if( rational == NULL )
       std::cout << "unknown" << std::flush;
-   else if( rational->isinf )
-      std::cout << (rational->val.sign() > 0 ? "+" : "-") << "infinity" << std::flush;
    else
-      std::cout << rational->val << std::flush;
+      std::cout << *rational << std::flush;
 }
 
 /** printf extension for rationals (not supporting all format options) */
@@ -2098,9 +2097,9 @@ SCIP_Real SCIPrationalGetReal(
 #else
    return rational->val.convert_to<SCIP_Real>(); /*lint !e838*/
 #endif
-#endif
-
+#else
    return 0.0;
+#endif
 }
 
 /** gets the relaxation of a rational as a real
@@ -2358,7 +2357,7 @@ void SCIPrationalComputeApproximationLong(
          res->isinf = FALSE;
          res->isfprepresentable = SCIP_ISFPREPRESENTABLE_UNKNOWN;
 
-         SCIPdebug(std::cout << "approximating " << src->val << " by " << res->val << std::endl);
+         SCIPdebug(std::cout << "approximating " << *src << " by " << *res << std::endl);
 
          return;
       }
@@ -2382,7 +2381,7 @@ void SCIPrationalComputeApproximationLong(
 
       done = 0;
 
-      SCIPdebug(std::cout << "approximating " << src->val << " by continued fractions with maxdenom " << maxdenom << std::endl);
+      SCIPdebug(std::cout << "approximating " << *src << " by continued fractions with maxdenom " << maxdenom << std::endl);
       SCIPdebug(std::cout << "confrac initial values: p0 " << p[1] << " q0 " << q[1] << " p1 " << p[2] << " q1 " << q[2] << std::endl);
 
       /* if q is already big, skip loop */
@@ -2563,7 +2562,7 @@ void SCIPrationalComputeApproximation(
          res->isinf = FALSE;
          res->isfprepresentable = SCIP_ISFPREPRESENTABLE_UNKNOWN;
 
-         SCIPdebug(std::cout << "approximating " << src->val << " by " << res->val << std::endl);
+         SCIPdebug(std::cout << "approximating " << *src << " by " << *res << std::endl);
 
          return;
       }
@@ -2584,7 +2583,7 @@ void SCIPrationalComputeApproximation(
 
       done = 0;
 
-      SCIPdebug(std::cout << "approximating " << src->val << " by continued fractions with maxdenom " << maxdenom << std::endl);
+      SCIPdebug(std::cout << "approximating " << *src << " by continued fractions with maxdenom " << maxdenom << std::endl);
       SCIPdebug(std::cout << "confrac initial values: p0 " << p[1] << " q0 " << q[1] << " p1 " << p[2] << " q1 " << q[2] << std::endl);
 
       /* if q is already big, skip loop */
